#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 clash-lib
version:              1.8.1
visibility:           public
id:                   clash-lib-1.8.1-DAAS2E9lo1ABNLwmjlWAG6
key:                  clash-lib-1.8.1-DAAS2E9lo1ABNLwmjlWAG6
license:              BSD-2-Clause
copyright:
    Copyright © 2012-2016, University of Twente,
    2016-2019, Myrtle Software Ltd,
    2017-2023, QBayLogic B.V., Google Inc.

maintainer:           QBayLogic B.V. <devops@qbaylogic.com>
author:               The Clash Authors
homepage:             https://clash-lang.org/
synopsis:
    Clash: a functional hardware description language - As a library

description:
    Clash is a functional hardware description language that borrows both its
    syntax and semantics from the functional programming language Haskell. The
    Clash compiler transforms these high-level descriptions to low-level
    synthesizable VHDL, Verilog, or SystemVerilog.

    Features of Clash:

    * Strongly typed, but with a very high degree of type inference, enabling both
    safe and fast prototyping using concise descriptions.

    * Interactive REPL: load your designs in an interpreter and easily test all
    your component without needing to setup a test bench.

    * Higher-order functions, with type inference, result in designs that are
    fully parametric by default.

    * Synchronous sequential circuit design based on streams of values, called
    @Signal@s, lead to natural descriptions of feedback loops.

    * Support for multiple clock domains, with type safe clock domain crossing.


    This package provides:

    * The CoreHW internal language: SystemF + Letrec + Case-decomposition

    * The normalisation process that brings CoreHW in a normal form that can be
    converted to a netlist

    * Blackbox/Primitive Handling


    Front-ends (for: parsing, typecheck, etc.) are provided by separate packages:

    * <https://hackage.haskell.org/package/clash-ghc GHC/Haskell Frontend>

    * <https://github.com/christiaanb/Idris-dev Idris Frontend>


    Prelude library: <https://hackage.haskell.org/package/clash-prelude>

category:             Hardware
abi:                  76ff94be12f90652a812e0f872439de9
exposed:              True
exposed-modules:
    Clash.Annotations.BitRepresentation.ClashLib Clash.Backend
    Clash.Backend.SystemVerilog Clash.Backend.VHDL
    Clash.Backend.Verilog Clash.Backend.Verilog.Time Clash.Core.DataCon
    Clash.Core.EqSolver Clash.Core.Evaluator.Types Clash.Core.FreeVars
    Clash.Core.HasFreeVars Clash.Core.HasType Clash.Core.Literal
    Clash.Core.Name Clash.Core.PartialEval
    Clash.Core.PartialEval.AsTerm Clash.Core.PartialEval.Monad
    Clash.Core.PartialEval.NormalForm Clash.Core.Pretty
    Clash.Core.Subst Clash.Core.Term Clash.Core.TermInfo
    Clash.Core.TermLiteral Clash.Core.TermLiteral.TH Clash.Core.TyCon
    Clash.Core.Type Clash.Core.TysPrim Clash.Core.Util Clash.Core.Var
    Clash.Core.VarEnv Clash.Data.UniqMap Clash.DataFiles Clash.Debug
    Clash.Driver Clash.Driver.Manifest Clash.Driver.Types
    Clash.Edalize.Edam Clash.Netlist Clash.Netlist.BlackBox
    Clash.Netlist.BlackBox.Parser Clash.Netlist.BlackBox.Types
    Clash.Netlist.BlackBox.Util Clash.Netlist.Expr Clash.Netlist.Id
    Clash.Netlist.Id.Common Clash.Netlist.Id.Internal
    Clash.Netlist.Id.SystemVerilog Clash.Netlist.Id.VHDL
    Clash.Netlist.Id.Verilog Clash.Netlist.Types Clash.Netlist.Util
    Clash.Normalize Clash.Normalize.PrimitiveReductions
    Clash.Normalize.Primitives Clash.Normalize.Strategy
    Clash.Normalize.Transformations Clash.Normalize.Transformations.ANF
    Clash.Normalize.Transformations.Case
    Clash.Normalize.Transformations.Cast
    Clash.Normalize.Transformations.DEC
    Clash.Normalize.Transformations.EtaExpand
    Clash.Normalize.Transformations.Inline
    Clash.Normalize.Transformations.Letrec
    Clash.Normalize.Transformations.MultiPrim
    Clash.Normalize.Transformations.Reduce
    Clash.Normalize.Transformations.SeparateArgs
    Clash.Normalize.Transformations.Specialize
    Clash.Normalize.Transformations.XOptimize Clash.Normalize.Types
    Clash.Normalize.Util Clash.Pretty
    Clash.Primitives.Annotations.SynthesisAttributes
    Clash.Primitives.DSL Clash.Primitives.GHC.Int
    Clash.Primitives.GHC.Literal Clash.Primitives.GHC.Word
    Clash.Primitives.Intel.ClockGen Clash.Primitives.Magic
    Clash.Primitives.Sized.Signed Clash.Primitives.Sized.ToInteger
    Clash.Primitives.Sized.Vector Clash.Primitives.Types
    Clash.Primitives.Util Clash.Primitives.Verification
    Clash.Primitives.Xilinx.ClockGen Clash.Rewrite.Combinators
    Clash.Rewrite.Types Clash.Rewrite.Util Clash.Rewrite.WorkFree
    Clash.Unique Clash.Util Clash.Util.Eq Clash.Util.Graph
    Clash.Util.Interpolate Clash.Verification.Pretty Data.Aeson.Extra
    Data.Text.Prettyprint.Doc.Extra GHC.BasicTypes.Extra

hidden-modules:
    Clash.Annotations.TopEntity.Extra Data.IntMap.Extra Data.List.Extra
    Data.Map.Ordered.Extra Data.Monoid.Extra
    Data.Primitive.ByteArray.Extra Data.Set.Ordered.Extra
    Data.Text.Extra GHC.SrcLoc.Extra Paths_clash_lib

import-dirs:          /usr/lib/ghc-9.2.8/site-local/clash-lib-1.8.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/clash-lib-1.8.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-clash-lib
hs-libraries:         HSclash-lib-1.8.1-DAAS2E9lo1ABNLwmjlWAG6
depends:
    aeson-2.1.2.1-4G6NRH3Yicj9TKX8fXoWTr
    aeson-pretty-0.8.10-3gMGTHlvRlNFcX72WIXlCa
    ansi-terminal-0.11.5-FgXvUwo3mIX2g72exyhUhE array-0.5.4.0
    async-2.2.5-Hxx4nU8aNwh7V1GfZTZX85
    attoparsec-0.14.4-7zFXPvsAeTc17D9FbG47Bq
    attoparsec-aeson-2.1.0.0-Dv7oW4CsUXjKQqMNZaLFPh base-4.16.4.0
    base16-bytestring-1.0.2.0-1EKQKfIbtqrKykCu8OdSyV binary-0.8.9.0
    bytestring-0.11.4.0 clash-prelude-1.8.1-7WdabReR9WiIXlkcwU7B8E
    concurrent-supply-0.1.8-DTnV9ni8P4BKkvW7JPxjHb containers-0.6.5.1
    cryptohash-sha256-0.11.102.1-57tLgDNX1OZ36vvrnU1ZF5
    data-binary-ieee754-0.4.4-5RBO9sqtqwKK43ihLnlB61
    data-default-0.7.1.1-JYvfHll1aet2HYdPlRdwv9 deepseq-1.4.6.1
    directory-1.3.6.2 dlist-1.0-LNr75TD4CZoKEEzkBmhWjA
    exceptions-0.10.4 extra-1.7.15-9PmwGQvWkElDwGNWrixqMB
    filepath-1.4.2.2 ghc-9.2.8 ghc-bignum-1.2 ghc-boot-th-9.2.8
    hashable-1.4.4.0-KJ184tiZpE52U0PEHxyV1r
    haskell-src-meta-0.8.12-Fe5kGltKJxeIZkKj5WAOn4
    hint-0.9.0.6-JRt1ievlEhSB0khxGtOG7
    infinite-list-0.1.1-9xKaT7EiNRGDfKwJvpGTWs
    lens-5.2.3-JhnKgAx9k76Jin0xTqnLw0 mtl-2.2.2
    ordered-containers-0.2.3-Ee6QR9weM8P1AVLTbz9WQP
    pretty-show-1.10-JwphvxEdk99BsHrT870tUy
    prettyprinter-1.7.1-6Wsg7uF6NF3C9EkVjlD5S1
    prettyprinter-interp-0.2.0.0-IbM6Icr08gJHXZtnWw45CC
    primitive-0.7.4.0-AQ7cOoBXu5aBgAQTQzTLUx
    string-interpolate-0.3.4.0-L3A8dPESgaj35YtlRCcSdH
    template-haskell-2.18.0.0 temporary-1.3-92h1kCtCGR4FaQHxoGuxwh
    terminal-size-0.3.4-7GJNKkuDjwr8c9rYP2Bu9E text-1.2.5.0
    time-1.11.1.1 transformers-0.5.6.2
    trifecta-2.1.4-5mBgLXKDpQ6BjTLgDz9Yl9
    unordered-containers-0.2.20-4hqmnCstShmJXjUlp61Lcu
    vector-0.13.1.0-xP3uH1g3cPFld8g0jCD5r
    vector-binary-instances-0.2.5.2-JbK0GaywNsMEVgxrIlAP6k
    yaml-0.11.11.2-5iEcWtzaUe01xKRCgCieOl

haddock-interfaces:   /usr/share/doc/haskell-clash-lib/html/clash-lib.haddock
haddock-html:         /usr/share/doc/haskell-clash-lib/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

